Auto-VTNA
=========
Python package for performing automatic variable time normalisation analysis (VTNA).VTNA is a kinetic analysis technique that can be used to derive reaction orders from concentration-time data from experiments with different initial concentrations of reactants, catalysts, additives or products. To learn more, check out the seminal work by Dr. Jordi Burés: https://onlinelibrary.wiley.com/doi/full/10.1002/anie.201609757, https://onlinelibrary.wiley.com/doi/full/10.1002/anie.201508983 and https://pubs.rsc.org/en/content/articlelanding/2019/sc/c8sc04698k. 

This work has been outlined in an open access paper: https://pubs.rsc.org/en/content/articlelanding/2024/dd/d4dd00111g. For further details on the theory behind and the package, see the ESI. 
For more info and user guides see https://github.com/ddalland/Auto-VTNA
A YouTube tutorial can be accessed at https://www.youtube.com/watch?v=FEDwvUY1Dl4&ab_channel=DanielDalland
